# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.mongodb.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.mongodb.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb3_6_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_2_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_4_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_4_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb5_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb5_0_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb6_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb6__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb6_0_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb6__0__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_database__pb2
from yandex.cloud.mdb.mongodb.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.mongodb.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/mdb/mongodb/v1/cluster_service.proto\x12\x1byandex.cloud.mdb.mongodb.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/mdb/mongodb/v1/backup.proto\x1a)yandex/cloud/mdb/mongodb/v1/cluster.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb3_6.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_0.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_4.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb4_4_enterprise.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb5_0.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb5_0_enterprise.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb6_0.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto\x1a*yandex/cloud/mdb/mongodb/v1/database.proto\x1a-yandex/cloud/mdb/mongodb/v1/maintenance.proto\x1a&yandex/cloud/mdb/mongodb/v1/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"g\n\x14ListClustersResponse\x12\x36\n\x08\x63lusters\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.mongodb.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xfe\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x04 \x03(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12K\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x30.yandex.cloud.mdb.mongodb.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x42\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12I\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32).yandex.cloud.mdb.mongodb.v1.DatabaseSpecB\x06\x82\xc8\x31\x02>0\x12\x41\n\nuser_specs\x18\x08 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.UserSpecB\x06\x82\xc8\x31\x02>0\x12\x41\n\nhost_specs\x18\t \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xb2\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x04 \x03(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12<\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12J\n\x12maintenance_window\x18\x07 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x9d\x06\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x04 \x03(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12K\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x30.yandex.cloud.mdb.mongodb.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x42\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12\x41\n\nhost_specs\x18\x07 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x63\n\x14recovery_target_spec\x18\n \x01(\x0b\x32\x45.yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest.RecoveryTargetSpec\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\x12RecoveryTargetSpec\x12\x19\n\ttimestamp\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xcc\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12g\n\x0freschedule_type\x18\x02 \x01(\x0e\x32H.yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"\xb0\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x07message\x18\x02 \x03(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12U\n\x0cservice_type\x18\x03 \x01(\x0e\x32?.yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\\\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0c\n\x08MONGOCFG\x10\x03\x12\t\n\x05\x41UDIT\x10\x04\"h\n\x17ListClusterLogsResponse\x12\x34\n\x04logs\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"d\n\x0fStreamLogRecord\x12\x36\n\x06record\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\xa3\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12W\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x41.yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\\\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0c\n\x08MONGOCFG\x10\x03\x12\t\n\x05\x41UDIT\x10\x04\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x1aListClusterBackupsResponse\x12\x34\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.mongodb.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"e\n\x18ListClusterHostsResponse\x12\x30\n\x05hosts\x18\x01 \x03(\x0b\x32!.yandex.cloud.mdb.mongodb.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"}\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\nhost_specs\x18\x02 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\x8d\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x11update_host_specs\x18\x02 \x03(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.UpdateHostSpecB\x06\x82\xc8\x31\x02>0\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\x86\x03\n\x0eUpdateHostSpec\x12 \n\thost_name\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=253\x12*\n\x06hidden\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x14secondary_delay_secs\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\x08priority\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x18\n\x10\x61ssign_public_ip\x18\x05 \x01(\x08\x12/\n\x0bupdate_mask\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x43\n\x04tags\x18\x07 \x03(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.UpdateHostSpec.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x04\n\x1c\x45nableClusterShardingRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12T\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x42.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoCfg\x12P\n\x06mongos\x18\x03 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.Mongos\x12\x41\n\nhost_specs\x18\x04 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12X\n\nmongoinfra\x18\x05 \x01(\x0b\x32\x44.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest.MongoInfra\x1aK\n\x08MongoCfg\x12?\n\tresources\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.ResourcesB\x04\xe8\xc7\x31\x01\x1aI\n\x06Mongos\x12?\n\tresources\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.ResourcesB\x04\xe8\xc7\x31\x01\x1aM\n\nMongoInfra\x12?\n\tresources\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.ResourcesB\x04\xe8\xc7\x31\x01\"3\n\x1d\x45nableClusterShardingMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"n\n\x16GetClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"z\n\x18ListClusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x19ListClusterShardsResponse\x12\x32\n\x06shards\x18\x01 \x03(\x0b\x32\".yandex.cloud.mdb.mongodb.v1.Shard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb1\x01\n\x16\x41\x64\x64\x43lusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x41\n\nhost_specs\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.mongodb.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"q\n\x19\x44\x65leteClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"D\n\x1a\x44\x65leteClusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"\\\n\x13ResetupHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\">\n\x14ResetupHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\\\n\x13RestartHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\">\n\x14RestartHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"]\n\x14StepdownHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"?\n\x15StepdownHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\xc5\x03\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12\x34\n\x04type\x18\x04 \x01(\x0e\x32&.yandex.cloud.mdb.mongodb.v1.Host.Type\x12.\n\nshard_name\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12*\n\x06hidden\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x14secondary_delay_secs\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\x08priority\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x04tags\x18\t \x03(\x0b\x32/.yandex.cloud.mdb.mongodb.v1.HostSpec.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\t\n\x0eMongodbSpec3_6\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6.MongoInfra\x1a\xd9\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xdd\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xd9\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xb4\x02\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig3_6\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig3_6\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xfb\t\n\x0eMongodbSpec4_0\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0.MongoInfra\x1a\xd9\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xdd\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xd9\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xb4\x02\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_0\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xfb\t\n\x0eMongodbSpec4_2\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2.MongoInfra\x1a\xd9\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xdd\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xd9\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xb4\x02\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xfb\t\n\x0eMongodbSpec4_4\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4.MongoInfra\x1a\xd9\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xdd\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xd9\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xb4\x02\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xe9\n\n\x19MongodbSpec4_4_enterprise\x12M\n\x06mongod\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongod\x12Q\n\x08mongocfg\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoCfg\x12M\n\x06mongos\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.Mongos\x12U\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterprise.MongoInfra\x1a\xe4\x01\n\x06Mongod\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xe8\x01\n\x08MongoCfg\x12P\n\x06\x63onfig\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xe4\x01\n\x06Mongos\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xca\x02\n\nMongoInfra\x12U\n\rconfig_mongos\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_4_enterprise\x12Y\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_4_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xfb\t\n\x0eMongodbSpec5_0\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0.MongoInfra\x1a\xd9\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xdd\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xd9\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xb4\x02\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xe9\n\n\x19MongodbSpec5_0_enterprise\x12M\n\x06mongod\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongod\x12Q\n\x08mongocfg\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoCfg\x12M\n\x06mongos\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.Mongos\x12U\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterprise.MongoInfra\x1a\xe4\x01\n\x06Mongod\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xe8\x01\n\x08MongoCfg\x12P\n\x06\x63onfig\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xe4\x01\n\x06Mongos\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xca\x02\n\nMongoInfra\x12U\n\rconfig_mongos\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0_enterprise\x12Y\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xfb\t\n\x0eMongodbSpec6_0\x12\x42\n\x06mongod\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0.Mongod\x12\x46\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0.MongoCfg\x12\x42\n\x06mongos\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0.Mongos\x12J\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0.MongoInfra\x1a\xd9\x01\n\x06Mongod\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xdd\x01\n\x08MongoCfg\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xd9\x01\n\x06Mongos\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xb4\x02\n\nMongoInfra\x12J\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0\x12N\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xe9\n\n\x19MongodbSpec6_0_enterprise\x12M\n\x06mongod\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0_enterprise.Mongod\x12Q\n\x08mongocfg\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0_enterprise.MongoCfg\x12M\n\x06mongos\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0_enterprise.Mongos\x12U\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0_enterprise.MongoInfra\x1a\xe4\x01\n\x06Mongod\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xe8\x01\n\x08MongoCfg\x12P\n\x06\x63onfig\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xe4\x01\n\x06Mongos\x12N\n\x06\x63onfig\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\x1a\xca\x02\n\nMongoInfra\x12U\n\rconfig_mongos\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise\x12Y\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12O\n\x15\x64isk_size_autoscaling\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.DiskSizeAutoscaling\"\xf1\t\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12%\n\x1d\x66\x65\x61ture_compatibility_version\x18\x05 \x01(\t\x12X\n\x10mongodb_spec_3_6\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec3_6H\x00R\x0fmongodbSpec_3_6\x12X\n\x10mongodb_spec_4_0\x18\x04 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_0H\x00R\x0fmongodbSpec_4_0\x12X\n\x10mongodb_spec_4_2\x18\x07 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_2H\x00R\x0fmongodbSpec_4_2\x12X\n\x10mongodb_spec_4_4\x18\x08 \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4H\x00R\x0fmongodbSpec_4_4\x12X\n\x10mongodb_spec_5_0\x18\n \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0H\x00R\x0fmongodbSpec_5_0\x12X\n\x10mongodb_spec_6_0\x18\x0e \x01(\x0b\x32+.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0H\x00R\x0fmongodbSpec_6_0\x12y\n\x1bmongodb_spec_4_4_enterprise\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec4_4_enterpriseH\x00R\x1amongodbSpec_4_4_enterprise\x12y\n\x1bmongodb_spec_5_0_enterprise\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec5_0_enterpriseH\x00R\x1amongodbSpec_5_0_enterprise\x12y\n\x1bmongodb_spec_6_0_enterprise\x18\x0f \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.MongodbSpec6_0_enterpriseH\x00R\x1amongodbSpec_6_0_enterprise\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x03 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x37-35\x12Z\n\x17performance_diagnostics\x18\r \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.PerformanceDiagnosticsConfig\x12\x33\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32#.yandex.cloud.mdb.mongodb.v1.AccessB\x0e\n\x0cmongodb_spec2\xe0)\n\x0e\x43lusterService\x12\x8e\x01\n\x03Get\x12..yandex.cloud.mdb.mongodb.v1.GetClusterRequest\x1a$.yandex.cloud.mdb.mongodb.v1.Cluster\"1\x82\xd3\xe4\x93\x02+\x12)/managed-mongodb/v1/clusters/{cluster_id}\x12\x91\x01\n\x04List\x12\x30.yandex.cloud.mdb.mongodb.v1.ListClustersRequest\x1a\x31.yandex.cloud.mdb.mongodb.v1.ListClustersResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-mongodb/v1/clusters\x12\xab\x01\n\x06\x43reate\x12\x31.yandex.cloud.mdb.mongodb.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02!\"\x1c/managed-mongodb/v1/clusters:\x01*\x12\xb8\x01\n\x06Update\x12\x31.yandex.cloud.mdb.mongodb.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.2)/managed-mongodb/v1/clusters/{cluster_id}:\x01*\x12\xc3\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.mdb.mongodb.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+*)/managed-mongodb/v1/clusters/{cluster_id}\x12\xb8\x01\n\x05Start\x12\x30.yandex.cloud.mdb.mongodb.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\"//managed-mongodb/v1/clusters/{cluster_id}:start\x12\xb4\x01\n\x04Stop\x12/.yandex.cloud.mdb.mongodb.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"./managed-mongodb/v1/clusters/{cluster_id}:stop\x12\xb7\x01\n\x04Move\x12/.yandex.cloud.mdb.mongodb.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"./managed-mongodb/v1/clusters/{cluster_id}:move:\x01*\x12\xbc\x01\n\x06\x42\x61\x63kup\x12\x31.yandex.cloud.mdb.mongodb.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x32\"0/managed-mongodb/v1/clusters/{cluster_id}:backup\x12\xb6\x01\n\x07Restore\x12\x32.yandex.cloud.mdb.mongodb.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02)\"$/managed-mongodb/v1/clusters:restore:\x01*\x12\xed\x01\n\x15RescheduleMaintenance\x12\x39.yandex.cloud.mdb.mongodb.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x44\"?/managed-mongodb/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xad\x01\n\x08ListLogs\x12\x33.yandex.cloud.mdb.mongodb.v1.ListClusterLogsRequest\x1a\x34.yandex.cloud.mdb.mongodb.v1.ListClusterLogsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-mongodb/v1/clusters/{cluster_id}:logs\x12\xb2\x01\n\nStreamLogs\x12\x35.yandex.cloud.mdb.mongodb.v1.StreamClusterLogsRequest\x1a,.yandex.cloud.mdb.mongodb.v1.StreamLogRecord\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-mongodb/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xc5\x01\n\x0eListOperations\x12\x39.yandex.cloud.mdb.mongodb.v1.ListClusterOperationsRequest\x1a:.yandex.cloud.mdb.mongodb.v1.ListClusterOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-mongodb/v1/clusters/{cluster_id}/operations\x12\xb9\x01\n\x0bListBackups\x12\x36.yandex.cloud.mdb.mongodb.v1.ListClusterBackupsRequest\x1a\x37.yandex.cloud.mdb.mongodb.v1.ListClusterBackupsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-mongodb/v1/clusters/{cluster_id}/backups\x12\xb1\x01\n\tListHosts\x12\x34.yandex.cloud.mdb.mongodb.v1.ListClusterHostsRequest\x1a\x35.yandex.cloud.mdb.mongodb.v1.ListClusterHostsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//managed-mongodb/v1/clusters/{cluster_id}/hosts\x12\xde\x01\n\x08\x41\x64\x64Hosts\x12\x33.yandex.cloud.mdb.mongodb.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xe7\x01\n\x0b\x44\x65leteHosts\x12\x36.yandex.cloud.mdb.mongodb.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\x12\xe7\x01\n\x0bUpdateHosts\x12\x36.yandex.cloud.mdb.mongodb.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*\x12\xed\x01\n\x0e\x45nableSharding\x12\x39.yandex.cloud.mdb.mongodb.v1.EnableClusterShardingRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*6\n\x1d\x45nableClusterShardingMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=\"8/managed-mongodb/v1/clusters/{cluster_id}:enableSharding:\x01*\x12\xaa\x01\n\x08GetShard\x12\x33.yandex.cloud.mdb.mongodb.v1.GetClusterShardRequest\x1a\".yandex.cloud.mdb.mongodb.v1.Shard\"E\x82\xd3\xe4\x93\x02?\x12=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xb5\x01\n\nListShards\x12\x35.yandex.cloud.mdb.mongodb.v1.ListClusterShardsRequest\x1a\x36.yandex.cloud.mdb.mongodb.v1.ListClusterShardsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-mongodb/v1/clusters/{cluster_id}/shards\x12\xc3\x01\n\x08\x41\x64\x64Shard\x12\x33.yandex.cloud.mdb.mongodb.v1.AddClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2* \n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x05Shard\x82\xd3\xe4\x93\x02\x35\"0/managed-mongodb/v1/clusters/{cluster_id}/shards:\x01*\x12\xe6\x01\n\x0b\x44\x65leteShard\x12\x36.yandex.cloud.mdb.mongodb.v1.DeleteClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*3\n\x1a\x44\x65leteClusterShardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?*=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xd7\x01\n\x0cResetupHosts\x12\x30.yandex.cloud.mdb.mongodb.v1.ResetupHostsRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*-\n\x14ResetupHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;\"6/managed-mongodb/v1/clusters/{cluster_id}:resetupHosts:\x01*\x12\xd7\x01\n\x0cRestartHosts\x12\x30.yandex.cloud.mdb.mongodb.v1.RestartHostsRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*-\n\x14RestartHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;\"6/managed-mongodb/v1/clusters/{cluster_id}:restartHosts:\x01*\x12\xdb\x01\n\rStepdownHosts\x12\x31.yandex.cloud.mdb.mongodb.v1.StepdownHostsRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*.\n\x15StepdownHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<\"7/managed-mongodb/v1/clusters/{cluster_id}:stepdownHosts:\x01*Bj\n\x1fyandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodb'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['environment']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['config_spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['database_specs']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['database_specs']._serialized_options = b'\202\3101\002>0'
  _CREATECLUSTERREQUEST.fields_by_name['user_specs']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['user_specs']._serialized_options = b'\202\3101\002>0'
  _CREATECLUSTERREQUEST.fields_by_name['host_specs']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTORECLUSTERREQUEST_LABELSENTRY._options = None
  _RESTORECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC.fields_by_name['timestamp']._options = None
  _RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC.fields_by_name['timestamp']._serialized_options = b'\372\3071\002>0'
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['name']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _RESTORECLUSTERREQUEST.fields_by_name['description']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _RESTORECLUSTERREQUEST.fields_by_name['environment']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['config_spec']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['host_specs']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._options = None
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._options = None
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _LOGRECORD_MESSAGEENTRY._options = None
  _LOGRECORD_MESSAGEENTRY._serialized_options = b'8\001'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['host_specs']._options = None
  _ADDCLUSTERHOSTSREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['host_names']._options = None
  _DELETECLUSTERHOSTSREQUEST.fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['update_host_specs']._options = None
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['update_host_specs']._serialized_options = b'\202\3101\002>0'
  _UPDATEHOSTSPEC_TAGSENTRY._options = None
  _UPDATEHOSTSPEC_TAGSENTRY._serialized_options = b'8\001'
  _UPDATEHOSTSPEC.fields_by_name['host_name']._options = None
  _UPDATEHOSTSPEC.fields_by_name['host_name']._serialized_options = b'\350\3071\001\212\3101\005<=253'
  _ENABLECLUSTERSHARDINGREQUEST_MONGOCFG.fields_by_name['resources']._options = None
  _ENABLECLUSTERSHARDINGREQUEST_MONGOCFG.fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _ENABLECLUSTERSHARDINGREQUEST_MONGOS.fields_by_name['resources']._options = None
  _ENABLECLUSTERSHARDINGREQUEST_MONGOS.fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA.fields_by_name['resources']._options = None
  _ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA.fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _ENABLECLUSTERSHARDINGREQUEST.fields_by_name['cluster_id']._options = None
  _ENABLECLUSTERSHARDINGREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ENABLECLUSTERSHARDINGREQUEST.fields_by_name['host_specs']._options = None
  _ENABLECLUSTERSHARDINGREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _GETCLUSTERSHARDREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERSHARDREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETCLUSTERSHARDREQUEST.fields_by_name['shard_name']._options = None
  _GETCLUSTERSHARDREQUEST.fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _LISTCLUSTERSHARDSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERSHARDSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSHARDSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSHARDSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSHARDSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSHARDSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _ADDCLUSTERSHARDREQUEST.fields_by_name['cluster_id']._options = None
  _ADDCLUSTERSHARDREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDCLUSTERSHARDREQUEST.fields_by_name['shard_name']._options = None
  _ADDCLUSTERSHARDREQUEST.fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _ADDCLUSTERSHARDREQUEST.fields_by_name['host_specs']._options = None
  _ADDCLUSTERSHARDREQUEST.fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _DELETECLUSTERSHARDREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERSHARDREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETECLUSTERSHARDREQUEST.fields_by_name['shard_name']._options = None
  _DELETECLUSTERSHARDREQUEST.fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _RESETUPHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _RESETUPHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESETUPHOSTSREQUEST.fields_by_name['host_names']._options = None
  _RESETUPHOSTSREQUEST.fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _RESTARTHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _RESTARTHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTARTHOSTSREQUEST.fields_by_name['host_names']._options = None
  _RESTARTHOSTSREQUEST.fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _STEPDOWNHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _STEPDOWNHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STEPDOWNHOSTSREQUEST.fields_by_name['host_names']._options = None
  _STEPDOWNHOSTSREQUEST.fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _HOSTSPEC_TAGSENTRY._options = None
  _HOSTSPEC_TAGSENTRY._serialized_options = b'8\001'
  _HOSTSPEC.fields_by_name['zone_id']._options = None
  _HOSTSPEC.fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['subnet_id']._options = None
  _HOSTSPEC.fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['shard_name']._options = None
  _HOSTSPEC.fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CONFIGSPEC.fields_by_name['backup_retain_period_days']._options = None
  _CONFIGSPEC.fields_by_name['backup_retain_period_days']._serialized_options = b'\372\3071\0047-35'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/managed-mongodb/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\036\022\034/managed-mongodb/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002!\"\034/managed-mongodb/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002.2)/managed-mongodb/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002+*)/managed-mongodb/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0021\"//managed-mongodb/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0020\"./managed-mongodb/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['Move']._options = None
  _CLUSTERSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0023\"./managed-mongodb/v1/clusters/{cluster_id}:move:\001*'
  _CLUSTERSERVICE.methods_by_name['Backup']._options = None
  _CLUSTERSERVICE.methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0022\"0/managed-mongodb/v1/clusters/{cluster_id}:backup'
  _CLUSTERSERVICE.methods_by_name['Restore']._options = None
  _CLUSTERSERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002)\"$/managed-mongodb/v1/clusters:restore:\001*'
  _CLUSTERSERVICE.methods_by_name['RescheduleMaintenance']._options = None
  _CLUSTERSERVICE.methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002D\"?/managed-mongodb/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _CLUSTERSERVICE.methods_by_name['ListLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0020\022./managed-mongodb/v1/clusters/{cluster_id}:logs'
  _CLUSTERSERVICE.methods_by_name['StreamLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\0027\0225/managed-mongodb/v1/clusters/{cluster_id}:stream_logs'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0026\0224/managed-mongodb/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListBackups']._options = None
  _CLUSTERSERVICE.methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0023\0221/managed-mongodb/v1/clusters/{cluster_id}/backups'
  _CLUSTERSERVICE.methods_by_name['ListHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\0021\022//managed-mongodb/v1/clusters/{cluster_id}/hosts'
  _CLUSTERSERVICE.methods_by_name['AddHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _CLUSTERSERVICE.methods_by_name['DeleteHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _CLUSTERSERVICE.methods_by_name['UpdateHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002@\";/managed-mongodb/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _CLUSTERSERVICE.methods_by_name['EnableSharding']._options = None
  _CLUSTERSERVICE.methods_by_name['EnableSharding']._serialized_options = b'\262\322*6\n\035EnableClusterShardingMetadata\022\025google.protobuf.Empty\202\323\344\223\002=\"8/managed-mongodb/v1/clusters/{cluster_id}:enableSharding:\001*'
  _CLUSTERSERVICE.methods_by_name['GetShard']._options = None
  _CLUSTERSERVICE.methods_by_name['GetShard']._serialized_options = b'\202\323\344\223\002?\022=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}'
  _CLUSTERSERVICE.methods_by_name['ListShards']._options = None
  _CLUSTERSERVICE.methods_by_name['ListShards']._serialized_options = b'\202\323\344\223\0022\0220/managed-mongodb/v1/clusters/{cluster_id}/shards'
  _CLUSTERSERVICE.methods_by_name['AddShard']._options = None
  _CLUSTERSERVICE.methods_by_name['AddShard']._serialized_options = b'\262\322* \n\027AddClusterShardMetadata\022\005Shard\202\323\344\223\0025\"0/managed-mongodb/v1/clusters/{cluster_id}/shards:\001*'
  _CLUSTERSERVICE.methods_by_name['DeleteShard']._options = None
  _CLUSTERSERVICE.methods_by_name['DeleteShard']._serialized_options = b'\262\322*3\n\032DeleteClusterShardMetadata\022\025google.protobuf.Empty\202\323\344\223\002?*=/managed-mongodb/v1/clusters/{cluster_id}/shards/{shard_name}'
  _CLUSTERSERVICE.methods_by_name['ResetupHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ResetupHosts']._serialized_options = b'\262\322*-\n\024ResetupHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002;\"6/managed-mongodb/v1/clusters/{cluster_id}:resetupHosts:\001*'
  _CLUSTERSERVICE.methods_by_name['RestartHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['RestartHosts']._serialized_options = b'\262\322*-\n\024RestartHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002;\"6/managed-mongodb/v1/clusters/{cluster_id}:restartHosts:\001*'
  _CLUSTERSERVICE.methods_by_name['StepdownHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['StepdownHosts']._serialized_options = b'\262\322*.\n\025StepdownHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002<\"7/managed-mongodb/v1/clusters/{cluster_id}:stepdownHosts:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=1071
  _globals['_GETCLUSTERREQUEST']._serialized_end=1124
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=1127
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=1271
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=1273
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=1376
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1379
  _globals['_CREATECLUSTERREQUEST']._serialized_end=2145
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2100
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2145
  _globals['_CREATECLUSTERMETADATA']._serialized_start=2147
  _globals['_CREATECLUSTERMETADATA']._serialized_end=2190
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2193
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2755
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2100
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2145
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2757
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2800
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2802
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2858
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2860
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2903
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2905
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2960
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2962
  _globals['_STARTCLUSTERMETADATA']._serialized_end=3004
  _globals['_STOPCLUSTERREQUEST']._serialized_start=3006
  _globals['_STOPCLUSTERREQUEST']._serialized_end=3060
  _globals['_STOPCLUSTERMETADATA']._serialized_start=3062
  _globals['_STOPCLUSTERMETADATA']._serialized_end=3103
  _globals['_MOVECLUSTERREQUEST']._serialized_start=3105
  _globals['_MOVECLUSTERREQUEST']._serialized_end=3204
  _globals['_MOVECLUSTERMETADATA']._serialized_start=3206
  _globals['_MOVECLUSTERMETADATA']._serialized_end=3304
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=3306
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=3362
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=3364
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=3407
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=3410
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=4207
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=2100
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=2145
  _globals['_RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC']._serialized_start=4160
  _globals['_RESTORECLUSTERREQUEST_RECOVERYTARGETSPEC']._serialized_end=4207
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=4209
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=4272
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=4275
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=4607
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=4497
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=4607
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=4609
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=4717
  _globals['_LOGRECORD']._serialized_start=4720
  _globals['_LOGRECORD']._serialized_end=4896
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=4850
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=4896
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=4899
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=5315
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5223
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5315
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=5317
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=5421
  _globals['_STREAMLOGRECORD']._serialized_start=5423
  _globals['_STREAMLOGRECORD']._serialized_end=5523
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=5526
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=5945
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5223
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5315
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=5947
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=6073
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=6075
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=6186
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=6188
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=6311
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=6313
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=6420
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=6422
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=6543
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=6545
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=6646
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=6648
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=6773
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=6775
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=6840
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=6842
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=6940
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=6942
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=7010
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=7013
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=7154
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=7156
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=7224
  _globals['_UPDATEHOSTSPEC']._serialized_start=7227
  _globals['_UPDATEHOSTSPEC']._serialized_end=7617
  _globals['_UPDATEHOSTSPEC_TAGSENTRY']._serialized_start=7574
  _globals['_UPDATEHOSTSPEC_TAGSENTRY']._serialized_end=7617
  _globals['_ENABLECLUSTERSHARDINGREQUEST']._serialized_start=7620
  _globals['_ENABLECLUSTERSHARDINGREQUEST']._serialized_end=8240
  _globals['_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG']._serialized_start=8011
  _globals['_ENABLECLUSTERSHARDINGREQUEST_MONGOCFG']._serialized_end=8086
  _globals['_ENABLECLUSTERSHARDINGREQUEST_MONGOS']._serialized_start=8088
  _globals['_ENABLECLUSTERSHARDINGREQUEST_MONGOS']._serialized_end=8161
  _globals['_ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA']._serialized_start=8163
  _globals['_ENABLECLUSTERSHARDINGREQUEST_MONGOINFRA']._serialized_end=8240
  _globals['_ENABLECLUSTERSHARDINGMETADATA']._serialized_start=8242
  _globals['_ENABLECLUSTERSHARDINGMETADATA']._serialized_end=8293
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_start=8295
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_end=8405
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_start=8407
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_end=8529
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_start=8531
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_end=8635
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_start=8638
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_end=8815
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_start=8817
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_end=8882
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_start=8884
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_end=8997
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_start=8999
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_end=9067
  _globals['_RESETUPHOSTSREQUEST']._serialized_start=9069
  _globals['_RESETUPHOSTSREQUEST']._serialized_end=9161
  _globals['_RESETUPHOSTSMETADATA']._serialized_start=9163
  _globals['_RESETUPHOSTSMETADATA']._serialized_end=9225
  _globals['_RESTARTHOSTSREQUEST']._serialized_start=9227
  _globals['_RESTARTHOSTSREQUEST']._serialized_end=9319
  _globals['_RESTARTHOSTSMETADATA']._serialized_start=9321
  _globals['_RESTARTHOSTSMETADATA']._serialized_end=9383
  _globals['_STEPDOWNHOSTSREQUEST']._serialized_start=9385
  _globals['_STEPDOWNHOSTSREQUEST']._serialized_end=9478
  _globals['_STEPDOWNHOSTSMETADATA']._serialized_start=9480
  _globals['_STEPDOWNHOSTSMETADATA']._serialized_end=9543
  _globals['_HOSTSPEC']._serialized_start=9546
  _globals['_HOSTSPEC']._serialized_end=9999
  _globals['_HOSTSPEC_TAGSENTRY']._serialized_start=7574
  _globals['_HOSTSPEC_TAGSENTRY']._serialized_end=7617
  _globals['_MONGODBSPEC3_6']._serialized_start=10002
  _globals['_MONGODBSPEC3_6']._serialized_end=11277
  _globals['_MONGODBSPEC3_6_MONGOD']._serialized_start=10305
  _globals['_MONGODBSPEC3_6_MONGOD']._serialized_end=10522
  _globals['_MONGODBSPEC3_6_MONGOCFG']._serialized_start=10525
  _globals['_MONGODBSPEC3_6_MONGOCFG']._serialized_end=10746
  _globals['_MONGODBSPEC3_6_MONGOS']._serialized_start=10749
  _globals['_MONGODBSPEC3_6_MONGOS']._serialized_end=10966
  _globals['_MONGODBSPEC3_6_MONGOINFRA']._serialized_start=10969
  _globals['_MONGODBSPEC3_6_MONGOINFRA']._serialized_end=11277
  _globals['_MONGODBSPEC4_0']._serialized_start=11280
  _globals['_MONGODBSPEC4_0']._serialized_end=12555
  _globals['_MONGODBSPEC4_0_MONGOD']._serialized_start=11583
  _globals['_MONGODBSPEC4_0_MONGOD']._serialized_end=11800
  _globals['_MONGODBSPEC4_0_MONGOCFG']._serialized_start=11803
  _globals['_MONGODBSPEC4_0_MONGOCFG']._serialized_end=12024
  _globals['_MONGODBSPEC4_0_MONGOS']._serialized_start=12027
  _globals['_MONGODBSPEC4_0_MONGOS']._serialized_end=12244
  _globals['_MONGODBSPEC4_0_MONGOINFRA']._serialized_start=12247
  _globals['_MONGODBSPEC4_0_MONGOINFRA']._serialized_end=12555
  _globals['_MONGODBSPEC4_2']._serialized_start=12558
  _globals['_MONGODBSPEC4_2']._serialized_end=13833
  _globals['_MONGODBSPEC4_2_MONGOD']._serialized_start=12861
  _globals['_MONGODBSPEC4_2_MONGOD']._serialized_end=13078
  _globals['_MONGODBSPEC4_2_MONGOCFG']._serialized_start=13081
  _globals['_MONGODBSPEC4_2_MONGOCFG']._serialized_end=13302
  _globals['_MONGODBSPEC4_2_MONGOS']._serialized_start=13305
  _globals['_MONGODBSPEC4_2_MONGOS']._serialized_end=13522
  _globals['_MONGODBSPEC4_2_MONGOINFRA']._serialized_start=13525
  _globals['_MONGODBSPEC4_2_MONGOINFRA']._serialized_end=13833
  _globals['_MONGODBSPEC4_4']._serialized_start=13836
  _globals['_MONGODBSPEC4_4']._serialized_end=15111
  _globals['_MONGODBSPEC4_4_MONGOD']._serialized_start=14139
  _globals['_MONGODBSPEC4_4_MONGOD']._serialized_end=14356
  _globals['_MONGODBSPEC4_4_MONGOCFG']._serialized_start=14359
  _globals['_MONGODBSPEC4_4_MONGOCFG']._serialized_end=14580
  _globals['_MONGODBSPEC4_4_MONGOS']._serialized_start=14583
  _globals['_MONGODBSPEC4_4_MONGOS']._serialized_end=14800
  _globals['_MONGODBSPEC4_4_MONGOINFRA']._serialized_start=14803
  _globals['_MONGODBSPEC4_4_MONGOINFRA']._serialized_end=15111
  _globals['_MONGODBSPEC4_4_ENTERPRISE']._serialized_start=15114
  _globals['_MONGODBSPEC4_4_ENTERPRISE']._serialized_end=16499
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOD']._serialized_start=15472
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOD']._serialized_end=15700
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOCFG']._serialized_start=15703
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOCFG']._serialized_end=15935
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOS']._serialized_start=15938
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOS']._serialized_end=16166
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA']._serialized_start=16169
  _globals['_MONGODBSPEC4_4_ENTERPRISE_MONGOINFRA']._serialized_end=16499
  _globals['_MONGODBSPEC5_0']._serialized_start=16502
  _globals['_MONGODBSPEC5_0']._serialized_end=17777
  _globals['_MONGODBSPEC5_0_MONGOD']._serialized_start=16805
  _globals['_MONGODBSPEC5_0_MONGOD']._serialized_end=17022
  _globals['_MONGODBSPEC5_0_MONGOCFG']._serialized_start=17025
  _globals['_MONGODBSPEC5_0_MONGOCFG']._serialized_end=17246
  _globals['_MONGODBSPEC5_0_MONGOS']._serialized_start=17249
  _globals['_MONGODBSPEC5_0_MONGOS']._serialized_end=17466
  _globals['_MONGODBSPEC5_0_MONGOINFRA']._serialized_start=17469
  _globals['_MONGODBSPEC5_0_MONGOINFRA']._serialized_end=17777
  _globals['_MONGODBSPEC5_0_ENTERPRISE']._serialized_start=17780
  _globals['_MONGODBSPEC5_0_ENTERPRISE']._serialized_end=19165
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOD']._serialized_start=18138
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOD']._serialized_end=18366
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOCFG']._serialized_start=18369
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOCFG']._serialized_end=18601
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOS']._serialized_start=18604
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOS']._serialized_end=18832
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA']._serialized_start=18835
  _globals['_MONGODBSPEC5_0_ENTERPRISE_MONGOINFRA']._serialized_end=19165
  _globals['_MONGODBSPEC6_0']._serialized_start=19168
  _globals['_MONGODBSPEC6_0']._serialized_end=20443
  _globals['_MONGODBSPEC6_0_MONGOD']._serialized_start=19471
  _globals['_MONGODBSPEC6_0_MONGOD']._serialized_end=19688
  _globals['_MONGODBSPEC6_0_MONGOCFG']._serialized_start=19691
  _globals['_MONGODBSPEC6_0_MONGOCFG']._serialized_end=19912
  _globals['_MONGODBSPEC6_0_MONGOS']._serialized_start=19915
  _globals['_MONGODBSPEC6_0_MONGOS']._serialized_end=20132
  _globals['_MONGODBSPEC6_0_MONGOINFRA']._serialized_start=20135
  _globals['_MONGODBSPEC6_0_MONGOINFRA']._serialized_end=20443
  _globals['_MONGODBSPEC6_0_ENTERPRISE']._serialized_start=20446
  _globals['_MONGODBSPEC6_0_ENTERPRISE']._serialized_end=21831
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOD']._serialized_start=20804
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOD']._serialized_end=21032
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOCFG']._serialized_start=21035
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOCFG']._serialized_end=21267
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOS']._serialized_start=21270
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOS']._serialized_end=21498
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOINFRA']._serialized_start=21501
  _globals['_MONGODBSPEC6_0_ENTERPRISE_MONGOINFRA']._serialized_end=21831
  _globals['_CONFIGSPEC']._serialized_start=21834
  _globals['_CONFIGSPEC']._serialized_end=23099
  _globals['_CLUSTERSERVICE']._serialized_start=23102
  _globals['_CLUSTERSERVICE']._serialized_end=28446
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OnPremiseMongo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    REPLICA_SET_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    port: builtins.int
    replica_set: builtins.str
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        port: builtins.int = ...,
        replica_set: builtins.str = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "port", b"port", "replica_set", b"replica_set", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremiseMongo = OnPremiseMongo

@typing.final
class MongoConnectionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    ON_PREMISE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    AUTH_SOURCE_FIELD_NUMBER: builtins.int
    mdb_cluster_id: builtins.str
    user: builtins.str
    """User name"""
    auth_source: builtins.str
    """Database name associated with the credentials"""
    @property
    def on_premise(self) -> global___OnPremiseMongo: ...
    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for user"""

    def __init__(
        self,
        *,
        mdb_cluster_id: builtins.str = ...,
        on_premise: global___OnPremiseMongo | None = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        auth_source: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "auth_source", b"auth_source", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise", "password", b"password", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["mdb_cluster_id", "on_premise"] | None: ...

global___MongoConnectionOptions = MongoConnectionOptions

@typing.final
class MongoConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def connection_options(self) -> global___MongoConnectionOptions: ...
    def __init__(
        self,
        *,
        connection_options: global___MongoConnectionOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "connection_options", b"connection_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "connection_options", b"connection_options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["connection_options"] | None: ...

global___MongoConnection = MongoConnection

@typing.final
class MongoCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    collection_name: builtins.str
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        collection_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["collection_name", b"collection_name", "database_name", b"database_name"]) -> None: ...

global___MongoCollection = MongoCollection

@typing.final
class MongoSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    COLLECTIONS_FIELD_NUMBER: builtins.int
    EXCLUDED_COLLECTIONS_FIELD_NUMBER: builtins.int
    SECONDARY_PREFERRED_MODE_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    secondary_preferred_mode: builtins.bool
    """Read mode for mongo client"""
    @property
    def connection(self) -> global___MongoConnection: ...
    @property
    def collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MongoCollection]:
        """List of collections for replication. Empty list implies replication of all
        tables on the deployment. Allowed to use * as collection name.
        """

    @property
    def excluded_collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MongoCollection]:
        """List of forbidden collections for replication. Allowed to use * as collection
        name for forbid all collections of concrete schema.
        """

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        connection: global___MongoConnection | None = ...,
        subnet_id: builtins.str = ...,
        collections: collections.abc.Iterable[global___MongoCollection] | None = ...,
        excluded_collections: collections.abc.Iterable[global___MongoCollection] | None = ...,
        secondary_preferred_mode: builtins.bool = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["collections", b"collections", "connection", b"connection", "excluded_collections", b"excluded_collections", "secondary_preferred_mode", b"secondary_preferred_mode", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___MongoSource = MongoSource

@typing.final
class MongoTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name"""
    cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType
    subnet_id: builtins.str
    @property
    def connection(self) -> global___MongoConnection: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        connection: global___MongoConnection | None = ...,
        database: builtins.str = ...,
        cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType = ...,
        subnet_id: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "connection", b"connection", "database", b"database", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___MongoTarget = MongoTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Config(google.protobuf.message.Message):
    """Test config."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    YAML_STRING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the test config. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the config belongs to."""
    yaml_string: builtins.str
    """Config content in YAML format."""
    name: builtins.str
    """Name of the config."""
    created_by: builtins.str
    """UA or SA that created the config."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        yaml_string: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "folder_id", b"folder_id", "id", b"id", "name", b"name", "yaml_string", b"yaml_string"]) -> None: ...

global___Config = Config



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.monitoring.v3.dashboard_pb2
import yandex.cloud.monitoring.v3.dashboard_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DashboardServiceStub:
    """A set of methods for managing dashboards."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.GetDashboardRequest,
        yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard,
    ]
    """Returns the specified dashboard."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsRequest,
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsResponse,
    ]
    """Retrieves the list of dashboards in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.CreateDashboardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new dashboard in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.UpdateDashboardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified dashboard."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.DeleteDashboardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified dashboard."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsRequest,
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsResponse,
    ]
    """Lists operations for the specified dashboard."""

class DashboardServiceAsyncStub:
    """A set of methods for managing dashboards."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.GetDashboardRequest,
        yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard,
    ]
    """Returns the specified dashboard."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsRequest,
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsResponse,
    ]
    """Retrieves the list of dashboards in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.CreateDashboardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new dashboard in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.UpdateDashboardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified dashboard."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.DeleteDashboardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified dashboard."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsRequest,
        yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsResponse,
    ]
    """Lists operations for the specified dashboard."""

class DashboardServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing dashboards."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.monitoring.v3.dashboard_service_pb2.GetDashboardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard, collections.abc.Awaitable[yandex.cloud.monitoring.v3.dashboard_pb2.Dashboard]]:
        """Returns the specified dashboard."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsResponse, collections.abc.Awaitable[yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardsResponse]]:
        """Retrieves the list of dashboards in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.monitoring.v3.dashboard_service_pb2.CreateDashboardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new dashboard in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.monitoring.v3.dashboard_service_pb2.UpdateDashboardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified dashboard."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.monitoring.v3.dashboard_service_pb2.DeleteDashboardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified dashboard."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsResponse, collections.abc.Awaitable[yandex.cloud.monitoring.v3.dashboard_service_pb2.ListDashboardOperationsResponse]]:
        """Lists operations for the specified dashboard."""

def add_DashboardServiceServicer_to_server(servicer: DashboardServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
